@@ -1,6 +1,6 @@
 package Config::Find;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 use strict;
 use warnings;
@@ -42,7 +42,7 @@ BEGIN {
             require Config::Find::Win7;
             @ISA=qw(Config::Find::Win7);
         } else {
-            croak "Unknow MSWin32 OS '$OS'";
+            croak "Unknown MSWin32 OS '$OS'";
         }
     } else {
         require Config::Find::Unix;
@@ -116,7 +116,7 @@ sub parse_opts {
 
 __END__
 
-=encoding utf-8
+=encoding latin1
 
 =head1 NAME
 
@@ -243,17 +243,12 @@ copies a configuration file to a convenient place.
 
 =back
 
-=head2 EXPORT
-
-None, this module has an OO interface.
-
 =head1 BUGS
 
 Some Win32 OSs are not completely implemented and default to inferior
 modes, but hey, this is a work in progress!!!
 
-Contributions, bug reports, feedback and any kind of comments are
-welcome.
+Contributions, bug reports, feedback and any kind of comments are welcome.
 
 =head1 SEE ALSO
 
@@ -269,9 +264,14 @@ L<Config::Auto> give me the idea for this module.
 
 Salvador Fandio Garca, E<lt>sfandino@yahoo.comE<gt>
 
+=head1 CONTRIBUTORS
+
+Barbie, E<lt>barbie@missbarbell.co.ukE<gt> (some bug fixes and documentation)
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2003-2015 by Salvador Fandio Garca (sfandino@yahoo.com)
+Copyright 2015 by Barbie (barbie@missbarbell.co.uk)
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
