@@ -1,6 +1,6 @@
 package Config::Find::Where;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 use strict;
 use warnings;
@@ -134,7 +134,7 @@ sub parse_opts {
 
 __END__
 
-=encoding utf-8
+=encoding latin1
 
 =head1 NAME
 
@@ -268,12 +268,13 @@ creates directory C<$dir> and any needed parents
 
 recursively creates all the non existant parent dirs for C<$file>.
 
+=item Config::Find::Where-E<gt>helper_path($file, %opts)
+
+searches for a script, based on the directories given in %opts, which are the
+same as bin_dir() method.
+
 =back
 
-=head2 EXPORT
-
-None, this module has an OO interface.
-
 =head1 BUGS
 
 Some Win32 OSs are not completely implemented and default to inferior
@@ -290,9 +291,14 @@ L<Config::Find>
 
 Salvador Fandio Garca, E<lt>sfandino@yahoo.comE<gt>
 
+=head1 CONTRIBUTORS
+
+Barbie, E<lt>barbie@missbarbell.co.ukE<gt> (some bug fixes and documentation)
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2003-2015 by Salvador Fandio Garca (sfandino@yahoo.com)
+Copyright 2015 by Barbie (barbie@missbarbell.co.uk)
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
